function accept = compute_proba_birth_death(y,alphaPlus, MUr, alphaPlus_star, MUr_star, R_star, R, sigma2r, sig2r_star,w_star,proba_b, proba_d)

%------------------------------------------------------------------
% This function allows ones to compute the acceptance ratio
% for the birth/death move
% 
% % INPUT
%         MPlus_star     : candidate of the mean of the endmember matrix
%         MPlus          : current state of the mean of the endmember matrix
%         alphaPlus_star : candidate of the abundance matrix
%         alphaPlus      : current state of the abundance matrix
%         R              : current state of the number components
%         sigma2r        : current state of the endmember's variance
%         sig2r_star     : candidate of the endmember's variance
%         y              : pixel to be unmixed
%         proba_d        : probabilities of death move 
%         proba_b        : probabilities of birth move
%         w_star         : added/removed abundance coefficient
% 
%
% OUTPUT
%       accept  :  equal to one if the new state is accepted
%                  zero otherwise 
%
%------------------------------------------------------------------
global L Rmax

if R_star == 1
      mu_alpha_star = MUr_star(:,R_star)*alphaPlus_star;
      C_alpha_star = sig2r_star(R_star)*alphaPlus_star^2;
      mu_alpha = MUr(:,1:R-1)*alphaPlus(1:R-1) + MUr(:,R)*(1-sum(alphaPlus(1:R-1)));
      C_alpha = sigma2r(1:R-1)'*(alphaPlus(1:R-1).^2) + sigma2r(R)*(1-sum(alphaPlus(1:R-1)))^2;
elseif R == 1
      mu_alpha = MUr(:,R)*alphaPlus;
      C_alpha = sigma2r(R)*alphaPlus^2;
      mu_alpha_star =MUr_star(:,1:R_star-1)*alphaPlus_star(1:R_star-1) + MUr_star(:,R_star)*(1-sum(alphaPlus_star(1:R_star-1)));
      C_alpha_star = sig2r_star(1:R_star-1)'*(alphaPlus_star(1:R_star-1).^2) + sig2r_star(R_star)*(1-sum(alphaPlus_star(1:R_star-1)))^2;
else      

    mu_alpha = MUr*alphaPlus ;
    C_alpha = sigma2r'*(alphaPlus.^2) ;
    mu_alpha_star =MUr_star*alphaPlus_star;
    C_alpha_star = sig2r_star'*(alphaPlus_star.^2);

end   

% likelihood ratio
A = (L/2)*log(C_alpha/C_alpha_star) + (((norm(y-mu_alpha))^2)/(2*C_alpha)...
                    - ((norm(y-mu_alpha_star))^2)/(2*C_alpha_star)) ; 
                
% Jacobian
if R_star-R == 1 %birth
        A = A + (R_star-1)*log(1-w_star); 
else
    if R_star == 1
        A = A;
    else    
        A = A - (R-2)*log(1-w_star);   
    end    
end

% proposal ratio (move)
if R_star-R == 1 %birth
    A = A + log(proba_d(R+1)) - log(proba_b(R));
else
    A = A - log(proba_d(R)) + log(proba_b(R-1));
end


% prior ratio (on the abundances)
if R_star-R == 1  %birth
        A  = A + log(R);
else
    if R_star == 1
        A = A;
    else    
        A  = A - log(R-1);
    end    
end
ratio = exp(A);

% final probability
proba_accept_move =  min([1, ratio]);

% sampling according to proba_accept_move
accept = gen_discrete([1 0],[proba_accept_move 1-proba_accept_move],1,1);

    