function accept = compute_proba_switch(y,MUr, MUr_star, alphaPlus, alphaPlus_star,R,R_star, sigma2r)

%------------------------------------------------------------------
% This function allows ones to compute the acceptance ratio
% for the switch move
% 
% % INPUT
%         MUr_star     : candidate of the mean of the endmember matrix
%         MUr          : current state of the mean of the endmember matrix
%         alphaPlus_star : candidate of the abundance matrix
%         alphaPlus      : current state of the abundance matrix
%         R              : current state of the number components
%         sigma2r        : current state of the endmember's variance
%         y              : pixel to be unmixed
%
% OUTPUT
%       accept  :  equal to one if the new state is accepted
%                  zero otherwise 
%
%------------------------------------------------------------------

global L Rmax

if R == 1 && R_star ==1
    mu_alpha = MUr(:,R)*alphaPlus;
    C_alpha = sigma2r(R)*alphaPlus^2;   
    mu_alpha_star =MUr_star(:,R)*alphaPlus_star;
    C_alpha_star = sigma2r(R)*alphaPlus_star^2;
else    
    mu_alpha = MUr*alphaPlus;
    C_alpha = sigma2r'*(alphaPlus.^2) ;    
    mu_alpha_star =MUr_star*alphaPlus_star;
    C_alpha_star = sigma2r'*(alphaPlus_star.^2) ;
end 


%likelihood ratio
A = (L/2)*log(C_alpha/C_alpha_star) + (((norm(y-mu_alpha))^2)/(2*C_alpha)...
                    - ((norm(y-mu_alpha_star))^2)/(2*C_alpha_star)) ; 

rapport = exp(A);

% final probability
proba_accept_move =  min([1, rapport]);

% sampling according to proba_accept_move
accept = gen_discrete([1 0],[proba_accept_move 1-proba_accept_move],1,1);