function [alpha_t, ind_M_t, R_t, sigma2r_t] = reversible_jump(y,R,ind,MUr,alphaPlus,sigma2r,proba_bdu)

global L Rmax
load library

proba_b = proba_bdu(1,:);
proba_d = proba_bdu(2,:);
proba_u = proba_bdu(3,:);

move_R = gen_discrete([-1 0 1],[proba_d(R) proba_u(R) proba_b(R)],1,1);

% the candidate R is set
R_star = R + move_R;

if R_star-R ~=0
    
    if move_R == 1
    % birth move

    % a spectrum is randomly added
    indM = gen_discrete(setdiff(1:Rmax,ind),ones(1,Rmax-R)/(Rmax-R),1,1);
    ind_star = [ind indM];
    MUr_star = lib_spectra(:,ind_star);
    
    % adding another abundance coefficient
    w_star = betarnd(1,R);
    C = 1/(1-w_star);
    alphaPlus_star = [(alphaPlus./C)',w_star]'; 
    
    % proposal distribution for sigma2r to avoid bad acceptance rates
    % D : hyperparameter tuning the "degree" of accepted moves (see
    % sample_sigma2r_rj.m for details)
    D = 1e-5;
    sig2r_star = sample_sigma2r_rj(alphaPlus, alphaPlus_star, sigma2r(1,:), D);
    sig2r_star = kron(sig2r_star,ones(R_star,1));
    
    else        
        % death move
        
        % a spectrum is randomly removed
        j = unidrnd(R);
        ind_star = ind;
        ind_star(j) = [];
        MUr_star = lib_spectra(:,ind_star);
        
        if R_star == 1
            alphaPlus_star = 1;
            w_star = 1;
        else    
            alphaPlus_star = alphaPlus;
            w_star = alphaPlus(j);
            alphaPlus_star(j) = [];
            C = sum(alphaPlus_star);
            alphaPlus_star = alphaPlus_star/C;
        end
        
    % proposal distribution for sigma2r to avoid bad acceptance rates
    % D : hyperparameter tuning the "degree" of accepted moves (see
    % sample_sigma2r_rj.m for details)    
    D = 1e-5;    
    sig2r_star = sample_sigma2r_rj(alphaPlus, alphaPlus_star, sigma2r(1,:),D);
    sig2r_star = kron(sig2r_star,ones(R_star,1));

    end    
    
        %Acceptance probability
        accept = compute_proba_birth_death(y,alphaPlus, MUr, alphaPlus_star, MUr_star, R_star, R, sigma2r, sig2r_star,w_star,proba_b, proba_d);        
        
        if accept == 1
            alpha_t = alphaPlus_star;
            ind_M_t = ind_star;
            R_t = R_star;
            sigma2r_t = sig2r_star;
        else
            alpha_t = alphaPlus;
            ind_M_t = ind;
            R_t = R;
            sigma2r_t = sigma2r;
        end    
        
else %switch move
    
     if Rmax-R~=0
        
        % index of the spectrum to be replaced
        indM = gen_discrete(1:R, ones(1,R)/R,1,1);

        % index of the spectrum to be added
        indMbis = gen_discrete(setdiff(1:Rmax,ind),ones(1,Rmax-R)/(Rmax-R),1,1);    
        ind_star = ind;
        ind_star(indM) = indMbis;

        % switching
        MUr_star = lib_spectra(:,ind_star);
        sig2r_star = sigma2r;
        alphaPlus_star = alphaPlus;
        R_star = R;
      
      %acceptance probability
      accept = compute_proba_switch(y,MUr, MUr_star, alphaPlus, alphaPlus_star,R,R_star, sigma2r);
      
        if accept == 1
            alpha_t = alphaPlus_star;
            ind_M_t = ind_star;
            R_t = R_star;
            sigma2r_t = sig2r_star;
        else
            alpha_t = alphaPlus;
            ind_M_t = ind;
            R_t = R;
            sigma2r_t = sigma2r;
        end  
        
     else
        
        % all the spectra are already involved
        alpha_t = alphaPlus;
        ind_M_t = ind;
        R_t = R;
        sigma2r_t = sigma2r;
    end
        
end  

