clc
clear all
close all

% loading: endmember spectra
load spectra.txt;
spectra = spectra-min(spectra(:));
[L tmp] = size(spectra);
N_spectra = tmp-1;

% wavelength
wave = spectra(:,1);

% matrix of all the spectra
M_all = spectra(:,2:end);

% step for the number of bands
p=3;

% vector of the endmember chosen for the mixture (here : 6 spectra)
endm_chosen = [1 2 3 4 5 6];
M = M_all(1:p:end,endm_chosen);

text = cell(1,6);
text{1} = 'Construction Concrete';
text{2} = 'Green Grass';
text{3} = 'Micaceous loam';
text{4} = 'Olive Green Paint';
text{5} = 'Bare Red Brick';
text{6} = 'Galvanized Steel Metal';


figure
for i = 1:6
subplot(3,2,i)
set(gca,'box','on')
set(gca,'fontsize',14)
plot(wave,M_all(:,i),'linewidth',1.6)    
title(text{i})
ylabel('Reflectance')
xlabel('Wavelength')
axis([0.3 2.6 0 1.1*max(M(:,i))])
end





% Library used for reversible jump algorithm
lib_spectra = M_all(1:p:end,:);
save library lib_spectra

% L = number of bands
% R = number of endmembers in the synthetic mixture
L = size(M,1);

% pixel abundances
alphaPlus = [0.5 0.15 0.35] ;
R = size(alphaPlus,2);
% by default : the three first spectra of the library are in the mixture


% Noise level (in dB) (for NCM mixtures)
SNRdb = 22;
SNR = 10^(SNRdb/10);
s = (norm(M(:,1:R)*alphaPlus(:,1))^2)/(L*SNR*(sum(alphaPlus(:,1).^2)));

y = zeros(L,R);
Mplus = zeros(L,R);

% resulting signal
% endmember vector construction
for r=1:R
    Mplus(:,r)=multrandn(M(:,r), s*eye(L),1);
end    

y = Mplus*alphaPlus';
%%

% Markov chain length
Nmc = 10000;

% number of burn-in period
Nbi = 2500;

% Unmixing procedure
tic
[TalphaPlus,TindMUr,Tsigma2r,TR] = unmixing(y,Nmc);
toc

%%
% exploitation

% Estimated number of endmembers 
result = exploitation_R(TR,Nbi,Nmc)

% Estimated spectra, abundances and variances
result = exploitation(TindMUr,TalphaPlus,Tsigma2r,TR,Nbi,Nmc);

