function result = exploitation(TindMUr,TalphaPlus,Tsigma2r,TR,Nbi,Nmc)

%------------------------------------------------------------------
% This function allows to exploit the results provided by
%       the function unmixing
% 
% INPUT
%       TalphaPlus : the samples \alpha^+ generated by the procedure
%       TindMUr  : the samples of the index spectra estimated by the reversible jump procedure       
%       TR : the samples R estimated by the reversible jump procedure 
%       Tsigma2r : the samples \sigma_r^2 generated by the procedure
%       Nbi   : number of burn-in iterations
%       Nmc   : length of the Markov Chain
%
% OUTPUT
%       result : 1 if the function is correctly used, 0 otherwise
%
%------------------------------------------------------------------
global L Rmax

Nr = Nmc - Nbi;

R = 3; %by default : 3 endmembers to be found

M = TindMUr(:,Nbi+1:Nmc);

% Histogram of the spectra index
% putting the correct combinations in a single class
% actual combination by default : {1,2,3} (3 first of the library)
ind3 = find(TR(Nbi+1:Nmc) == R);
M_ind3 = M(:,ind3);
M_ind3 = reshape(M_ind3(M_ind3>0),R,length(M_ind3(M_ind3>0))/R);
compt12 = 0;
compt125 = 0;
ind12 = [];
ind125 = [];

% combination by default to be looked for {1,2,3}
possible_perms = perms([1 2 3]);
for k = 1:length(M_ind3)
    if any(possible_perms'==kron(M_ind3(:,k),ones(1,length(possible_perms))),2)
        compt12 = compt12 + 1;
        ind12 = [ind12 k];
    else
        compt125 = compt125 + 1;
        ind125 = [ind125 k];
    end
end

figure
set(gca,'fontsize',12)
bar([1 2],[length(ind12) length(ind125)]/length(ind3),'k')
axis([0.5 2.5 0 1])
set(gca,'xticklabel',{'actual combination' 'other combinations'})
result = 1;

% posterior distribution of abundances conditioned to the combination {1,2,3}
TalphaPlus = TalphaPlus(:,Nbi+1:end);
TalphaPlus3 = TalphaPlus(:,ind3);

for z = 1:length(ind12)
    TalphaPlus12(:,z) = TalphaPlus3(M_ind3(:,ind12(z)),ind12(z));
end   

% Abundances not necesarily in the correct order
M_ind3(:,1) % showing the index of the spectrum studied
figure
for i=1:R
    Talphai = TalphaPlus12(i,:);
    xmin = min(Talphai)*0.8;
    xmax = max(Talphai)*1.2;
    Nc = sqrt(Nmc-Nbi+1);
    pas = (xmax-xmin)/Nc;
    subplot(1,R,i)
    set(gca,'fontsize',12)
    h = hist(Talphai,xmin:pas:xmax);
    plot(xmin:pas:xmax,h,'k')
    set(gca,'ytick',[]);
    axis([xmin xmax 0 max(h)*1.1]);
    switch i
        case 1
          %  axis([0.2 0.4 0 max(h)*1.1]);
            ylabel('f(a_1|M^+=[S_1 S_2 S_3 S_5],Y)');
        case 2
          %  axis([0.4 0.6 0 max(h)*1.1]);
            ylabel('f(a_2|M^+=[S_1 S_2 S_3 S_5],Y)');
        case 3
            ylabel('f(a_3|M^+=[S_1 S_2 S_3 S_5],Y)');
        case 4
            ylabel('f(a_4|M^+=[S_1 S_2 S_3 S_5],Y)');    
          %  axis([0.1 0.3 0 max(h)*1.1]);
    end
end


% posterior distribution of variance conditioned to the combination {1,2,3}
Tsigma2r12 = Tsigma2r(:,ind12+Nbi);

figure
xmin = min(Tsigma2r12)*0.8;
xmax = max(Tsigma2r12)*1.2;
Nc = sqrt(Nmc-Nbi+1);
pas = (xmax-xmin)/Nc;
set(gca,'fontsize',16)
h = hist(Tsigma2r12(1,:),xmin:pas:xmax);
plot(xmin:pas:xmax,h,'k')
set(gca,'ytick',[]);
ylabel('f(\sigma^2|M^+=[S_1 S_2 S_3],Y)');


